@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphySingle.cpp,v 1.23.4.1 2005/09/09 14:43:32 chpe Exp $
+ *  $Id: EphySingle.cpp,v 1.25 2005/10/12 19:45:06 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -45,6 +45,7 @@ NS_IMPL_ISUPPORTS1(EphySingle, nsIObserver)
 
 EphySingle::EphySingle()
 : mOwner(nsnull)
+, mIsOnline(PR_TRUE) /* nsIOService doesn't send an initial notification, assume we start on-line */
 {
 	LOG ("EphySingle ctor");
 }
@@ -233,11 +234,9 @@ NS_IMETHODIMP EphySingle::Observe(nsISupports *aSubject,
 	else if (strcmp (aTopic, "network:offline-status-changed") == 0)
 	{
 		/* aData is either (PRUnichar[]) "offline" or "online" */
-		gboolean offline;
+		mIsOnline = (aData && aData[0] == 'o' && aData[1] == 'n');
 
-		offline = (aData[1] == 'f');
-
-		g_signal_emit_by_name (mOwner, "network-status", offline);
+		g_object_notify (G_OBJECT (mOwner), "network-status");
 	}
 	else
 	{
