@@ -1,6 +1,8 @@
 /*  vim:set ts=8 noet sw=8:
  *  Copyright (C) 2000-2004 Marco Pesenti Gritti
- *  Copyright (C) 2003, 2004 Christian Persch
+ *  Copyright (C) 2003 Robert Marcano
+ *  Copyright (C) 2003, 2004, 2005, 2006 Christian Persch
+ *  Copyright (C) 2005 Crispin Flowerday
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-embed-single.cpp,v 1.120 2005/11/08 13:10:10 chpe Exp $
+ *  $Id: mozilla-embed-single.cpp,v 1.127 2006/01/16 23:51:40 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -28,11 +30,13 @@
 #include "ephy-cookie-manager.h"
 #include "ephy-password-manager.h"
 #include "ephy-permission-manager.h"
+#include "ephy-certificate-manager.h"
 #include "ephy-embed-shell.h"
 
 #include "glib.h"
 #include "ephy-debug.h"
 #include "gtkmozembed.h"
+#include "gtkmozembed_internal.h"
 #include "mozilla-embed.h"
 #include "ephy-file-helpers.h"
 #include "mozilla-notifiers.h"
@@ -44,6 +48,7 @@
 #include "EphyBrowser.h"
 #include "EphyUtils.h"
 #include "MozillaPrivate.h"
+#include "mozilla-x509-cert.h"
 
 #include <glib/gi18n.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
@@ -68,6 +73,15 @@
 #include <nsILocalFile.h>
 #include <nsIURI.h>
 
+#if defined(HAVE_MOZILLA_TOOLKIT) && defined(HAVE_GECKO_1_8)
+#include "EphyDirectoryProvider.h"
+#endif
+
+#ifdef HAVE_MOZILLA_PSM
+#include <nsIX509Cert.h>
+#include <nsIX509CertDB.h>
+#endif
+
 #ifdef HAVE_NSIPASSWORD_H
 #include <nsIPassword.h>
 #endif
@@ -90,11 +104,24 @@
 
 #include <stdlib.h>
 
+#ifdef ENABLE_NETWORK_MANAGER
+#include <libnm_glib.h>
+#endif
+
+#ifdef HAVE_GECKO_1_8
+#include <nsIURI.h>
+#include <nsIStyleSheetService.h>
+#include "EphyUtils.h"
+#include "ephy-file-helpers.h"
+#endif
+
 #define MOZILLA_PROFILE_DIR  "/mozilla"
 #define MOZILLA_PROFILE_NAME "epiphany"
 #define MOZILLA_PROFILE_FILE "prefs.js"
 #define DEFAULT_PROFILE_FILE SHARE_DIR"/default-prefs.js"
 
+#define USER_CSS_LOAD_DELAY 500 /* ms */
+
 #define MOZILLA_EMBED_SINGLE_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), MOZILLA_TYPE_EMBED_SINGLE, MozillaEmbedSinglePrivate))
 
 struct MozillaEmbedSinglePrivate
@@ -106,6 +133,17 @@ struct MozillaEmbedSinglePrivate
 
 	EphySingle *mSingleObserver;
 
+#ifdef ENABLE_NETWORK_MANAGER
+	libnm_glib_ctx *nm_context;
+	guint nm_callback_id;
+#endif
+#ifdef HAVE_GECKO_1_8
+        char *user_css_uri;
+        guint user_css_enabled_notifier_id;
+        EphyFileMonitor *user_css_file_monitor;
+        guint user_css_enabled : 1;
+#endif
+
 	guint online : 1;
 };
 
@@ -122,6 +160,10 @@ static void ephy_password_manager_iface_init	(EphyPasswordManagerIface *iface);
 static void ephy_permission_manager_iface_init	(EphyPermissionManagerIface *iface);
 static void mozilla_embed_single_init		(MozillaEmbedSingle *ges);
 
+#ifdef ENABLE_CERTIFICATE_MANAGER
+static void ephy_certificate_manager_iface_init	(EphyCertificateManagerIface *iface);
+#endif
+
 static GObjectClass *parent_class = NULL;
 
 GType
@@ -172,6 +214,15 @@ mozilla_embed_single_get_type (void)
 			NULL
 		};
 
+#ifdef ENABLE_CERTIFICATE_MANAGER
+		static const GInterfaceInfo certificate_manager_info =
+		{
+			(GInterfaceInitFunc) ephy_certificate_manager_iface_init,
+			NULL,
+			NULL
+		};
+#endif
+
 		type = g_type_register_static (G_TYPE_OBJECT,
 					       "MozillaEmbedSingle",
 					       &our_info,
@@ -192,6 +243,11 @@ mozilla_embed_single_get_type (void)
 		g_type_add_interface_static (type,
 					     EPHY_TYPE_PERMISSION_MANAGER,
 					     &permission_manager_info);
+#ifdef ENABLE_CERTIFICATE_MANAGER
+		g_type_add_interface_static (type,
+					     EPHY_TYPE_CERTIFICATE_MANAGER,
+					     &certificate_manager_info);
+#endif
 	}
 
         return type;
@@ -490,6 +546,212 @@ mozilla_init_observer (MozillaEmbedSingle *single)
 	}
 }
 
+#ifdef ENABLE_NETWORK_MANAGER
+
+static void
+network_state_cb (libnm_glib_ctx *context,
+		  gpointer data)
+{
+	EphyEmbedSingle *single = EPHY_EMBED_SINGLE (data);
+	libnm_glib_state state;
+
+	state = libnm_glib_get_network_state (context);
+
+	LOG ("Network state: %d\n", state);
+
+	switch (state)
+	{
+		case LIBNM_NO_DBUS:
+		case LIBNM_NO_NETWORKMANAGER:
+		case LIBNM_INVALID_CONTEXT:
+			/* do nothing */
+			break;
+		case LIBNM_NO_NETWORK_CONNECTION:
+			ephy_embed_single_set_network_status (single, FALSE);
+			break;
+		case LIBNM_ACTIVE_NETWORK_CONNECTION:
+			ephy_embed_single_set_network_status (single, TRUE);
+			break;
+	}
+}
+
+static void
+mozilla_init_network_manager (MozillaEmbedSingle *single)
+{
+	MozillaEmbedSinglePrivate *priv = single->priv;
+
+	priv->nm_context = libnm_glib_init ();
+	if (priv->nm_context == NULL)
+	{
+		g_warning ("Could not initialise NetworkManager, connection status will not be managed!\n");
+		return;
+	}
+
+	priv->nm_callback_id = libnm_glib_register_callback (priv->nm_context,
+							     network_state_cb,
+							     single, NULL);
+	if (priv->nm_callback_id == 0)
+	{
+		libnm_glib_shutdown (priv->nm_context);
+		priv->nm_context = NULL;
+
+		g_warning ("Could not connect to NetworkManager, connection status will not be managed!\n");
+		return;
+	}
+}
+
+#endif /* ENABLE_NETWORK_MANAGER */
+
+#ifdef HAVE_GECKO_1_8
+
+static void
+user_css_register (MozillaEmbedSingle *single)
+{
+	MozillaEmbedSinglePrivate *priv = single->priv;
+
+	nsresult rv;
+	nsCOMPtr<nsIURI> uri;
+	rv = EphyUtils::NewURI (getter_AddRefs (uri),
+				nsDependentCString (priv->user_css_uri));
+	NS_ENSURE_SUCCESS (rv, );
+
+	nsCOMPtr<nsIStyleSheetService> service
+			(do_GetService ("@mozilla.org/content/style-sheet-service;1", &rv));
+	NS_ENSURE_SUCCESS (rv, );
+
+	rv = service->LoadAndRegisterSheet (uri, nsIStyleSheetService::AGENT_SHEET);
+	if (NS_FAILED (rv))
+	{
+		g_warning ("Registering the user stylesheet failed (rv=%x)!\n", rv);
+	}
+}
+
+static void
+user_css_unregister (MozillaEmbedSingle *single)
+{
+	MozillaEmbedSinglePrivate *priv = single->priv;
+
+	nsresult rv;
+	nsCOMPtr<nsIURI> uri;
+	rv = EphyUtils::NewURI (getter_AddRefs (uri),
+				nsDependentCString (priv->user_css_uri));
+	NS_ENSURE_SUCCESS (rv, );
+
+	nsCOMPtr<nsIStyleSheetService> service
+			(do_GetService ("@mozilla.org/content/style-sheet-service;1", &rv));
+	NS_ENSURE_SUCCESS (rv, );
+
+	PRBool isRegistered = PR_FALSE;
+	rv = service->SheetRegistered (uri, nsIStyleSheetService::USER_SHEET,
+				       &isRegistered);
+	if (NS_SUCCEEDED (rv) && isRegistered)
+	{
+		rv = service->UnregisterSheet (uri, nsIStyleSheetService::USER_SHEET);
+	}
+	if (NS_FAILED (rv))
+	{
+		g_warning ("Unregistering the user stylesheet failed (rv=%x)!\n", rv);
+	}
+}
+
+static void
+user_css_file_monitor_func (EphyFileMonitor *,
+			    const char *,
+			    MozillaEmbedSingle *single)
+{
+	LOG ("Reregistering the user style sheet");
+
+	user_css_unregister (single);
+	user_css_register (single);
+}
+
+static void
+user_css_enabled_notify (GConfClient *client,
+			 guint cnxn_id,
+			 GConfEntry *entry,
+			 MozillaEmbedSingle *single)
+{
+	MozillaEmbedSinglePrivate *priv = single->priv;
+	guint enabled;
+
+	enabled = eel_gconf_get_boolean (CONF_USER_CSS_ENABLED) != FALSE;
+	if (priv->user_css_enabled == enabled) return;
+
+	LOG ("User stylesheet enabled: %s", enabled ? "t" : "f");
+
+	priv->user_css_enabled = enabled;
+
+        if (enabled)
+	{
+		user_css_register (single);
+
+		g_assert (priv->user_css_file_monitor == NULL);
+		priv->user_css_file_monitor =
+			ephy_file_monitor_add (priv->user_css_uri,
+						GNOME_VFS_MONITOR_FILE,
+						USER_CSS_LOAD_DELAY,
+						(EphyFileMonitorFunc) user_css_file_monitor_func,
+						NULL,
+						single);
+	}
+        else
+	{
+		if (priv->user_css_file_monitor != NULL)
+		{
+			ephy_file_monitor_cancel (priv->user_css_file_monitor);
+			priv->user_css_file_monitor = NULL;
+		}
+
+		user_css_unregister (single);
+	}
+}
+
+static void
+mozilla_stylesheet_init (MozillaEmbedSingle *single)
+{
+	MozillaEmbedSinglePrivate *priv = single->priv;
+	char *user_css_file;
+
+	user_css_file = g_build_filename (ephy_dot_dir (),
+					  USER_STYLESHEET_FILENAME,
+					  NULL);
+	priv->user_css_uri = gnome_vfs_get_uri_from_local_path (user_css_file);
+	g_free (user_css_file);
+
+	user_css_enabled_notify (NULL, 0, NULL, single);
+	priv->user_css_enabled_notifier_id =
+		eel_gconf_notification_add
+			(CONF_USER_CSS_ENABLED,
+			 (GConfClientNotifyFunc) user_css_enabled_notify,
+			 single);
+}
+
+static void
+mozilla_stylesheet_shutdown (MozillaEmbedSingle *single)
+{
+	MozillaEmbedSinglePrivate *priv = single->priv;
+
+	if (priv->user_css_enabled_notifier_id != 0)
+	{
+		eel_gconf_notification_remove (priv->user_css_enabled_notifier_id);
+		priv->user_css_enabled_notifier_id = 0;
+	}
+
+	if (priv->user_css_file_monitor != NULL)
+	{
+		ephy_file_monitor_cancel (priv->user_css_file_monitor);
+		priv->user_css_file_monitor = NULL;
+	}
+
+	if (priv->user_css_uri != NULL)
+	{
+		g_free (priv->user_css_uri);
+		priv->user_css_uri = NULL;
+	}
+}
+
+#endif /* HAVE_GECKO_1_8 */
+
 static gboolean
 init_services (MozillaEmbedSingle *single)
 {
@@ -501,9 +763,19 @@ init_services (MozillaEmbedSingle *single)
 	/* Set mozilla binary path */
 	gtk_moz_embed_set_comp_path (MOZILLA_HOME);
 
+#if defined(HAVE_MOZILLA_TOOLKIT) && defined(HAVE_GECKO_1_8)
+
+	nsCOMPtr<nsIDirectoryServiceProvider> dp = new EphyDirectoryProvider ();
+	if (!dp) return FALSE;
+
+	gtk_moz_embed_set_directory_service_provider (dp);
+#endif
+
 	/* Fire up the beast */
 	gtk_moz_embed_push_startup ();
 
+	mozilla_register_components ();
+
 	/* Until gtkmozembed does this itself */
 	mozilla_init_chrome ();
 
@@ -523,10 +795,16 @@ init_services (MozillaEmbedSingle *single)
 	mozilla_notifiers_init ();
 	STOP_PROFILER ("Mozilla prefs notifiers")
 
-	mozilla_register_components ();
-
 	mozilla_init_observer (single);
 
+#ifdef ENABLE_NETWORK_MANAGER
+	mozilla_init_network_manager (single);
+#endif
+
+#ifdef HAVE_GECKO_1_8
+        mozilla_stylesheet_init (single);
+#endif
+
 	return TRUE;
 }
 
@@ -581,14 +859,34 @@ static void
 mozilla_embed_single_dispose (GObject *object)
 {
 	MozillaEmbedSingle *single = MOZILLA_EMBED_SINGLE (object);
+	MozillaEmbedSinglePrivate *priv = single->priv;
 
-	if (single->priv->mSingleObserver)
+#ifdef HAVE_GECKO_1_8
+        mozilla_stylesheet_shutdown (single);
+#endif
+
+	if (priv->mSingleObserver)
 	{
-		single->priv->mSingleObserver->Detach ();
-		NS_RELEASE (single->priv->mSingleObserver);
-		single->priv->mSingleObserver = nsnull;
+		priv->mSingleObserver->Detach ();
+		NS_RELEASE (priv->mSingleObserver);
+		priv->mSingleObserver = nsnull;
 	}
 
+#ifdef ENABLE_NETWORK_MANAGER
+        if (priv->nm_context != NULL)
+	{
+		if (priv->nm_callback_id != 0)
+		{
+			libnm_glib_unregister_callback (priv->nm_context,
+							priv->nm_callback_id);
+			priv->nm_callback_id = 0;
+		}
+	
+		libnm_glib_shutdown (priv->nm_context);
+		priv->nm_context = NULL;
+	}
+#endif
+
 	parent_class->dispose (object);
 }
 
@@ -1009,6 +1307,124 @@ impl_open_window (EphyEmbedSingle *single,
 	return EphyUtils::FindEmbed (newWindow);
 }
 
+#ifdef ENABLE_CERTIFICATE_MANAGER
+
+static gboolean
+impl_remove_certificate (EphyCertificateManager *manager,
+			 EphyX509Cert *cert)
+{
+	nsresult rv;
+
+	nsCOMPtr<nsIX509CertDB> certDB;
+	certDB = do_GetService (NS_X509CERTDB_CONTRACTID);
+	if (!certDB) return FALSE;
+
+        nsCOMPtr<nsIX509Cert> mozCert;
+        rv = mozilla_x509_cert_get_mozilla_cert (MOZILLA_X509_CERT (cert),
+						 getter_AddRefs (mozCert));
+	if (NS_FAILED (rv)) return FALSE;
+
+	rv = certDB->DeleteCertificate (mozCert);
+	if (NS_FAILED (rv)) return FALSE;
+
+        return TRUE;
+}
+
+#define NICK_DELIMITER PRUnichar('\001')
+
+static GList *
+retrieveCerts (PRUint32 type)
+{
+	nsresult rv;
+
+	nsCOMPtr<nsIX509CertDB> certDB;
+	certDB = do_GetService (NS_X509CERTDB_CONTRACTID);
+	if (!certDB) return NULL;
+
+	PRUint32 count;
+	PRUnichar **certNameList = NULL;
+
+	rv = certDB->FindCertNicknames (NULL, type, &count, &certNameList);
+	if (NS_FAILED (rv)) return NULL;
+
+	LOG("Certificates found: %i", count);
+
+	GList *list = NULL;
+	for (PRUint32 i = 0; i < count; i++)
+	{
+		/* HACK HACK, this is EVIL, the string for each cert is:
+		     <DELIMITER>nicknameOrEmailAddress<DELIMITER>dbKey
+		   So we need to chop off the dbKey to look it up in the database.
+		   
+		   https://bugzilla.mozilla.org/show_bug.cgi?id=214742
+		*/
+		nsEmbedCString full_string;
+		NS_UTF16ToCString (nsEmbedString(certNameList[i]),
+				   NS_CSTRING_ENCODING_UTF8, full_string);
+
+		const char *key = full_string.get();
+		char *pos = strrchr (key, NICK_DELIMITER);
+		if (!pos) continue;
+
+		nsCOMPtr<nsIX509Cert> mozilla_cert;
+		rv = certDB->FindCertByDBKey (pos, NULL, getter_AddRefs (mozilla_cert));
+		if (NS_FAILED (rv)) continue;
+
+		MozillaX509Cert *cert = mozilla_x509_cert_new (mozilla_cert);
+		list = g_list_prepend (list, cert);
+	}
+
+	NS_FREE_XPCOM_ALLOCATED_POINTER_ARRAY (count, certNameList);
+	return list;
+}
+
+static GList *
+impl_get_certificates (EphyCertificateManager *manager,
+		       EphyX509CertType type)
+{
+	int moz_type = nsIX509Cert::USER_CERT;
+	switch (type)
+	{
+		case PERSONAL_CERTIFICATE:
+			moz_type = nsIX509Cert::USER_CERT;
+			break;
+		case SERVER_CERTIFICATE:
+			moz_type = nsIX509Cert::SERVER_CERT;
+			break;
+		case CA_CERTIFICATE:
+			moz_type = nsIX509Cert::CA_CERT;
+			break;
+	}
+	return retrieveCerts (moz_type);
+}
+
+static gboolean
+impl_import (EphyCertificateManager *manager,
+	     const gchar *file)
+{
+	nsresult rv;
+	nsCOMPtr<nsIX509CertDB> certDB;
+	certDB = do_GetService (NS_X509CERTDB_CONTRACTID);
+	if (!certDB) return FALSE;
+
+	nsCOMPtr<nsILocalFile> localFile;
+	localFile = do_CreateInstance (NS_LOCAL_FILE_CONTRACTID);
+
+	// TODO Is this correct ?
+	nsEmbedString path;
+	NS_CStringToUTF16 (nsEmbedCString(file),
+			   NS_CSTRING_ENCODING_UTF8, path);
+
+
+	localFile->InitWithPath (path);
+	rv = certDB->ImportPKCS12File(NULL, localFile);
+	if (NS_FAILED (rv)) return FALSE;
+
+	return TRUE;
+}
+
+#endif /* ENABLE_CERTIFICATE_MANAGER */
+
 static void
 mozilla_embed_single_get_property (GObject *object,
 				   guint prop_id,
@@ -1093,3 +1509,15 @@ ephy_permission_manager_iface_init (EphyPermissionManagerIface *iface)
 	iface->test = impl_permission_manager_test;
 	iface->list = impl_permission_manager_list;
 }
+
+#ifdef ENABLE_CERTIFICATE_MANAGER
+
+static void
+ephy_certificate_manager_iface_init (EphyCertificateManagerIface *iface)
+{
+	iface->get_certificates = impl_get_certificates;
+	iface->remove_certificate = impl_remove_certificate;
+	iface->import = impl_import;
+}
+
+#endif /* ENABLE_CERTIFICATE_MANAGER */
