@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-file-helpers.c,v 1.32.2.1 2005/12/30 19:28:34 chpe Exp $
+ *  $Id: ephy-file-helpers.c,v 1.40 2006/01/16 23:51:40 chpe Exp $
  */
 
 #include "config.h"
@@ -44,12 +44,10 @@
 #undef GNOME_DISABLE_DEPRECATED
 #include <libgnome/gnome-desktop-item.h>
 
-#ifdef HAVE_STARTUP_NOTIFICATION
 #define SN_API_NOT_YET_FROZEN
 #include <libsn/sn.h>
 #include <gdk/gdk.h>
 #include <gdk/gdkx.h>
-#endif
 
 #define EPHY_UUID		"0d82d98f-7079-401c-abff-203fcde1ece3"
 #define EPHY_UUID_ENVVAR	"EPHY_UNIQUE"
@@ -111,6 +109,48 @@ ephy_file_downloads_dir (void)
 	return downloads_dir;
 }
 
+char *
+ephy_file_get_downloads_dir (void)
+{
+	char *download_dir, *expanded;
+
+	download_dir = eel_gconf_get_string (CONF_STATE_DOWNLOAD_DIR);
+
+	if (download_dir && strcmp (download_dir, "Downloads") == 0)
+	{
+		g_free (download_dir);
+		download_dir = ephy_file_downloads_dir ();
+	}
+  	else if (download_dir && strcmp (download_dir, "Desktop") == 0)
+	{
+		g_free (download_dir);
+		download_dir = ephy_file_desktop_dir ();
+	}  
+	else if (download_dir)
+	{
+		char *converted_dp;
+
+		converted_dp = g_filename_from_utf8 (download_dir, -1, NULL, NULL, NULL);
+		g_free (download_dir);
+		download_dir = converted_dp;
+	}
+
+	/* Emergency download destination */
+	if (download_dir == NULL)
+	{
+		const char *home_dir;
+		home_dir = g_get_home_dir ();
+		download_dir = g_strdup (home_dir != NULL ? home_dir : "/");
+	}
+
+	g_return_val_if_fail (download_dir != NULL, NULL);
+
+	expanded = gnome_vfs_expand_initial_tilde (download_dir);
+	g_free (download_dir);
+
+	return expanded;
+}
+
 char *
 ephy_file_desktop_dir (void)
 {
@@ -284,13 +324,13 @@ ephy_ensure_dir_exists (const char *dir)
 	{
 		if (g_file_test (dir, G_FILE_TEST_EXISTS) == TRUE)
 		{
-			g_warning (_("%s exists, please move it out of the way."), dir);
+			g_warning (_("\"%s\" exists, please move it out of the way."), dir);
 			return FALSE;
 		}
 
 		if (mkdir (dir, 488) != 0)
 		{
-			g_warning (_("Failed to create directory %s."), dir);
+			g_warning (_("Failed to create directory \"%s\"."), dir);
 			return FALSE;
 		}
 	}
@@ -519,7 +559,6 @@ my_gdk_spawn_make_environment_for_screen (GdkScreen  *screen,
   return retval;
 }
 
-#ifdef HAVE_STARTUP_NOTIFICATION
 static void
 sn_error_trap_push (SnDisplay *display,
 		    Display   *xdisplay)
@@ -687,8 +726,6 @@ add_startup_timeout (GdkScreen         *screen,
 	}
 }
 
-#endif /* HAVE_STARTUP_NOTIFICATION */
-
 gboolean
 ephy_file_launch_application (GnomeVFSMimeApplication *application,
 			      const char *parameter,
@@ -699,10 +736,8 @@ ephy_file_launch_application (GnomeVFSMimeApplication *application,
 	char            *uri;
 	char           **envp;
 	GnomeVFSResult   result;
-#ifdef HAVE_STARTUP_NOTIFICATION
 	SnLauncherContext *sn_context;
 	SnDisplay *sn_display;
-#endif
 
 	g_return_val_if_fail (application != NULL, FALSE);
 	g_return_val_if_fail (parameter != NULL, FALSE);
@@ -715,7 +750,6 @@ ephy_file_launch_application (GnomeVFSMimeApplication *application,
 	screen = gdk_screen_get_default ();
 	envp = my_gdk_spawn_make_environment_for_screen (screen, NULL);
 	
-#ifdef HAVE_STARTUP_NOTIFICATION
 	sn_display = sn_display_new (gdk_display,
 				     sn_error_trap_push,
 				     sn_error_trap_pop);
@@ -766,11 +800,9 @@ ephy_file_launch_application (GnomeVFSMimeApplication *application,
 	} else {
 		sn_context = NULL;
 	}
-#endif /* HAVE_STARTUP_NOTIFICATION */
 	
 	result = gnome_vfs_mime_application_launch_with_env (application, uris, envp);
 
-#ifdef HAVE_STARTUP_NOTIFICATION
 	if (sn_context != NULL) {
 		if (result != GNOME_VFS_OK) {
 			sn_launcher_context_complete (sn_context); /* end sequence */
@@ -783,7 +815,6 @@ ephy_file_launch_application (GnomeVFSMimeApplication *application,
 	}
 	
 	sn_display_unref (sn_display);
-#endif /* HAVE_STARTUP_NOTIFICATION */
 
 	g_strfreev (envp);
 	g_list_foreach (uris, (GFunc) g_free,NULL);
@@ -923,3 +954,151 @@ ephy_file_launch_handler (const char *mime_type,
 
 	return ret;
 }
+
+#define DELAY_MAX_TICKS	64
+
+struct _EphyFileMonitor
+{
+	GnomeVFSMonitorHandle *handle;
+	EphyFileMonitorFunc callback;
+	EphyFileMonitorDelayFunc delay_func;
+	gpointer user_data;
+	char *uri;
+	guint delay;
+	guint timeout_id;
+	guint ticks;
+};
+
+static gboolean
+ephy_file_monitor_timeout_cb (EphyFileMonitor *monitor)
+{
+	if (monitor->ticks > 0)
+	{
+		monitor->ticks--;
+
+		/* Run again */
+		return TRUE;
+	}
+
+	if (monitor->delay_func &&
+	    monitor->delay_func (monitor, monitor->user_data))
+	{
+		monitor->ticks = DELAY_MAX_TICKS / 2;
+
+		/* Run again */
+		return TRUE;
+	}
+
+	monitor->timeout_id = 0;
+
+	monitor->callback (monitor, monitor->uri, monitor->user_data);
+
+	/* don't run again */
+	return FALSE;
+}
+
+static void
+ephy_file_monitor_cb (GnomeVFSMonitorHandle *handle,
+		      const char *monitor_uri,
+		      const char *info_uri,
+		      GnomeVFSMonitorEventType event_type,
+		      EphyFileMonitor *monitor)
+{
+	LOG ("File '%s' has changed, scheduling reload", monitor_uri);
+
+	switch (event_type)
+	{
+		case GNOME_VFS_MONITOR_EVENT_CHANGED:
+		case GNOME_VFS_MONITOR_EVENT_CREATED:
+			/* We make a lot of assumptions here, but basically we know
+			 * that we just have to reload, by construction.
+			 * Delay the reload a little bit so we don't endlessly
+			 * reload while a file is written.
+			 */
+			if (monitor->ticks == 0)
+			{
+				monitor->ticks = 1;
+			}
+			else
+			{
+				/* Exponential backoff */
+				monitor->ticks = MIN (monitor->ticks * 2,
+						      DELAY_MAX_TICKS);
+			}
+
+			if (monitor->timeout_id == 0)
+			{
+				monitor->timeout_id = 
+					g_timeout_add (monitor->delay,
+						       (GSourceFunc) ephy_file_monitor_timeout_cb,
+						       monitor);
+			}
+
+			break;
+
+		case GNOME_VFS_MONITOR_EVENT_DELETED:
+		case GNOME_VFS_MONITOR_EVENT_STARTEXECUTING:
+		case GNOME_VFS_MONITOR_EVENT_STOPEXECUTING:
+		case GNOME_VFS_MONITOR_EVENT_METADATA_CHANGED:
+		default:
+			break;
+	}
+}
+
+EphyFileMonitor *
+ephy_file_monitor_add (const char *uri,
+		       GnomeVFSMonitorType monitor_type,
+		       guint delay,
+		       EphyFileMonitorFunc callback,
+		       EphyFileMonitorDelayFunc delay_func,
+		       gpointer user_data)
+{
+	EphyFileMonitor *monitor;
+
+	g_return_val_if_fail (uri != NULL, NULL);
+	g_return_val_if_fail (callback, NULL);
+
+	monitor = g_new (EphyFileMonitor, 1);
+	monitor->callback = callback;
+	monitor->delay_func = delay_func;
+	monitor->user_data = user_data;
+	monitor->uri = g_strdup (uri);
+	monitor->delay = delay;
+	monitor->ticks = 0;
+	monitor->timeout_id = 0;
+
+	if (gnome_vfs_monitor_add (&monitor->handle, uri, monitor_type,
+				   (GnomeVFSMonitorCallback) ephy_file_monitor_cb,
+				   monitor) != GNOME_VFS_OK)
+	{
+		LOG ("Failed to add file monitor for '%s'", uri);
+
+		g_free (monitor->uri);
+		g_free (monitor);
+		return NULL;
+	}
+
+	LOG ("File monitor for '%s' added", uri);
+
+	return monitor;
+}
+
+void
+ephy_file_monitor_cancel (EphyFileMonitor *monitor)
+{
+	g_return_if_fail (monitor != NULL);
+	g_return_if_fail (monitor->handle != NULL);
+	g_return_if_fail (monitor->uri != NULL);
+
+	LOG ("Cancelling file monitor for '%s'", monitor->uri);
+
+	gnome_vfs_monitor_cancel (monitor->handle);
+
+	if (monitor->timeout_id != 0)
+	{
+		g_source_remove (monitor->timeout_id);
+	}
+
+	g_free (monitor->uri);
+	g_free (monitor);
+}
