@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-stock-icons.c,v 1.16.6.1 2005/10/20 13:13:54 chpe Exp $
+ *  $Id: ephy-stock-icons.c,v 1.21 2006/01/16 22:25:16 paharvey Exp $
  */
 
 #include "config.h"
@@ -43,6 +43,7 @@ ephy_stock_icons_init (void)
 		STOCK_VIEW_SOURCE,
 		STOCK_SEND_MAIL,
 		STOCK_ADD_BOOKMARK,
+		STOCK_BOOKMARK,
 		STOCK_PRINT_SETUP,
 		STOCK_LOCK_INSECURE,
 		STOCK_LOCK_SECURE,
@@ -51,7 +52,6 @@ ephy_stock_icons_init (void)
 
 	static const GtkStockItem items[] =
 	{
-		{ EPHY_STOCK_CLOSE_TAB,	N_("Close Tab"),	0, 0, NULL },
 		{ EPHY_STOCK_POPUPS,	N_("Popup Windows"),	0, 0, NULL },
 		{ EPHY_STOCK_HISTORY,	N_("History"),		0, 0, NULL },
 		{ EPHY_STOCK_BOOKMARKS, N_("Bookmarks"),	0, 0, NULL },
@@ -60,39 +60,41 @@ ephy_stock_icons_init (void)
 	};
 
 	factory = gtk_icon_factory_new ();
-	gtk_icon_factory_add_default (factory);
 
 	for (i = 0; i < (int) G_N_ELEMENTS (items); i++)
 	{
 		char *fn;
 
-		icon_set = gtk_icon_set_new ();
 		icon_source = gtk_icon_source_new ();
 
 		fn = g_strconcat (items[i].stock_id, ".png", NULL);
+		gtk_icon_source_set_icon_name (icon_source, items[i].stock_id);
 		gtk_icon_source_set_filename (icon_source, ephy_file (fn));
 		g_free (fn);
 
+		icon_set = gtk_icon_set_new ();
 		gtk_icon_set_add_source (icon_set, icon_source);
+		gtk_icon_source_free (icon_source);
+
 		gtk_icon_factory_add (factory, items[i].stock_id, icon_set);
 		gtk_icon_set_unref (icon_set);
-		gtk_icon_source_free (icon_source);
 	}
 
 	gtk_stock_add_static (items, G_N_ELEMENTS (items));
 
 	for (i = 0; i < (int) G_N_ELEMENTS (icon_theme_items); i++)
 	{
-		icon_set = gtk_icon_set_new ();
 		icon_source = gtk_icon_source_new ();
 		gtk_icon_source_set_icon_name (icon_source, icon_theme_items[i]);
+
+		icon_set = gtk_icon_set_new ();
 		gtk_icon_set_add_source (icon_set, icon_source);
+		gtk_icon_source_free (icon_source);
+
 		gtk_icon_factory_add (factory, icon_theme_items[i], icon_set);
 		gtk_icon_set_unref (icon_set);
-		gtk_icon_source_free (icon_source);
 	}
 
-	g_object_unref (G_OBJECT (factory));
-
-	gtk_icon_size_register (EPHY_ICON_SIZE_TAB_BUTTON, 10, 10);
+	gtk_icon_factory_add_default (factory);
+	g_object_unref (factory);
 }
