@@ -15,12 +15,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-search-entry.c,v 1.8 2004/10/27 19:54:57 chpe Exp $
+ *  $Id: ephy-search-entry.c,v 1.10 2005/01/08 19:41:46 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include <gtk/gtklabel.h>
 #include <glib/gi18n.h>
@@ -33,7 +31,7 @@ static void ephy_search_entry_init (EphySearchEntry *entry);
 
 #define EPHY_SEARCH_ENTRY_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_SEARCH_ENTRY, EphySearchEntryPrivate))
 
-struct EphySearchEntryPrivate
+struct _EphySearchEntryPrivate
 {
 	gboolean clearing;
 
