@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-bookmark-properties.h,v 1.4.16.1 2004/11/01 14:08:33 chpe Exp $
+ *  $Id: ephy-bookmark-properties.h,v 1.7 2006/01/16 23:03:28 paharvey Exp $
  */
 
 #ifndef EPHY_BOOKMARK_PROPERTIES_H
@@ -34,7 +34,7 @@ G_BEGIN_DECLS
 #define EPHY_IS_BOOKMARK_PROPERTIES_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_BOOKMARK_PROPERTIES))
 #define EPHY_BOOKMARK_PROPERTIES_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), EPHY_TYPE_BOOKMARK_PROPERTIES, EphyBookmarkPropertiesClass))
 
-typedef struct EphyBookmarkPropertiesPrivate EphyBookmarkPropertiesPrivate;
+typedef struct _EphyBookmarkPropertiesPrivate EphyBookmarkPropertiesPrivate;
 
 typedef struct
 {
@@ -53,7 +53,7 @@ GType		     ephy_bookmark_properties_get_type        (void);
 
 GtkWidget	    *ephy_bookmark_properties_new             (EphyBookmarks *bookmarks,
 							       EphyNode *bookmark,
-							       GtkWidget *parent_window);
+							       gboolean creating);
 
 EphyNode            *ephy_bookmark_properties_get_node        (EphyBookmarkProperties *properties);
 
