@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: ephy-bookmarks-editor.c,v 1.180 2005/11/08 12:47:17 chpe Exp $
+ * $Id: ephy-bookmarks-editor.c,v 1.181 2006/01/16 23:03:26 paharvey Exp $
  */
 
 #include "config.h"
@@ -48,6 +48,7 @@
 #include "ephy-bookmarks-editor.h"
 #include "ephy-bookmarks-import.h"
 #include "ephy-bookmarks-export.h"
+#include "ephy-bookmarks-ui.h"
 #include "ephy-node-common.h"
 #include "ephy-node-view.h"
 #include "ephy-window.h"
@@ -461,8 +462,7 @@ static void
 show_properties_dialog (EphyBookmarksEditor *editor,
 			EphyNode *bookmark)
 {
-	ephy_bookmarks_show_bookmark_properties
-		(editor->priv->bookmarks, bookmark, GTK_WIDGET (editor));
+	ephy_bookmarks_ui_show_bookmark (GTK_WIDGET (editor), bookmark);
 }
 
 static GSList *
