@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id$
+ *  $Id: ephy-main.c,v 1.44 2006/01/03 21:01:13 crispin Exp $
  */
 
 #include "config.h"
@@ -35,7 +35,6 @@
 #include <gtk/gtkmessagedialog.h>
 #include <gdk/gdkx.h>
 #include <libgnome/gnome-program.h>
-#include <bonobo/bonobo-main.h>
 #include <glib/gi18n.h>
 #include <libgnomevfs/gnome-vfs-init.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
@@ -47,18 +46,19 @@ static gboolean open_in_existing = FALSE;
 static gboolean open_in_new_tab = FALSE;
 static gboolean open_fullscreen = FALSE;
 static gboolean open_as_bookmarks_editor = FALSE;
+static gboolean reload_plugins = FALSE;
 
-static const char *session_filename = NULL;
-static const char *bookmark_url = NULL;
-static const char *bookmarks_file = NULL;
+static char *session_filename = NULL;
+static char *bookmark_url = NULL;
+static char *bookmarks_file = NULL;
 
 static struct poptOption popt_options[] =
 {
 	{ "new-tab", 'n', POPT_ARG_NONE, &open_in_new_tab, 0,
-	  N_("Open a new tab in an existing Epiphany window"),
+	  N_("Open a new tab in an existing window"),
 	  NULL },
 	{ "fullscreen", 'f', POPT_ARG_NONE, &open_fullscreen, 0,
-	  N_("Run Epiphany in full screen mode"),
+	  N_("Run in full screen mode"),
 	  NULL },
 	{ "load-session", 'l', POPT_ARG_STRING, &session_filename, 0,
 	  N_("Load the given session file"),
@@ -72,6 +72,7 @@ static struct poptOption popt_options[] =
 	{ "bookmarks-editor", 'b', POPT_ARG_NONE, &open_as_bookmarks_editor, 0,
 	  N_("Launch the bookmarks editor"),
 	  NULL },
+	{ "reload-plugins", '\0', POPT_ARG_NONE, &reload_plugins, 0, NULL, NULL },
 	{ NULL, 0, 0, NULL, 0, NULL, NULL }
 };
 
@@ -174,7 +175,7 @@ slowly_and_stupidly_obtain_timestamp (Display *xdisplay)
 		XChangeProperty (xdisplay, 
 				 xwindow, atom_name,
 				 atom_type,
-				 8, PropModeReplace, name, strlen (name));
+				 8, PropModeReplace, (unsigned char *)name, strlen (name));
 	}
 	
 	XWindowEvent (xdisplay,
@@ -217,15 +218,18 @@ main (int argc, char *argv[])
 	program = gnome_program_init (PACKAGE, VERSION,
                                       LIBGNOMEUI_MODULE, argc, argv,
                                       GNOME_PARAM_POPT_TABLE, popt_options,
-                                      GNOME_PARAM_HUMAN_READABLE_NAME, _("Ephy"),
+                                      GNOME_PARAM_HUMAN_READABLE_NAME, _("Web Browser"),
 				      GNOME_PARAM_APP_DATADIR, DATADIR,
                                       NULL);
 
 	/* Get a timestamp manually if need be */
 	if (user_time == 0)
+	{
 		user_time = slowly_and_stupidly_obtain_timestamp (gdk_display);
+	}
 
-	g_set_application_name (_("Epiphany Web Browser"));
+	/* sets the name to appear in the window list applet when grouping windows */
+	g_set_application_name (_("Web Browser"));
 
 	/* Set default window icon */
 	gtk_window_set_default_icon_name ("web-browser");
@@ -282,8 +286,6 @@ main (int argc, char *argv[])
 	gtk_about_dialog_set_url_hook (handle_url, NULL, NULL);
 	gtk_about_dialog_set_email_hook (handle_email, NULL, NULL);
 
-	bonobo_activate ();
-
 	ephy_shell_new ();
 	g_assert (ephy_shell != NULL);
 	new_instance = ephy_shell_startup (ephy_shell, startup_flags,
