@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-session.c,v 1.46 2005/10/12 19:33:39 chpe Exp $
+ *  $Id: ephy-session.c,v 1.49 2005/12/23 19:18:05 cneumair Exp $
  */
 
 #include "config.h"
@@ -358,7 +358,7 @@ ephy_session_class_init (EphySessionClass *class)
 		 		      "Active Window",
 		 		      "The active window",
 				      EPHY_TYPE_WINDOW,
-				      G_PARAM_READABLE));
+				      G_PARAM_READABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
 	g_type_class_add_private (object_class, sizeof (EphySessionPrivate));
 }
@@ -389,6 +389,7 @@ offer_to_resume (EphySession *session,
 
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Crash Recovery"));
 	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
+	gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
 
 	session->priv->resume_dialog = dialog;
@@ -741,8 +742,6 @@ parse_embed (xmlNodePtr child,
 	     EphyWindow *window,
 	     EphySession *session)
 {
-	EphySessionPrivate *priv = session->priv;
-
 	while (child != NULL)
 	{
 		if (strcmp ((char *) child->name, "embed") == 0)
