@@ -16,26 +16,31 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-toolbars-model.c,v 1.35 2005/01/28 22:24:46 chpe Exp $
+ *  $Id: ephy-toolbars-model.c,v 1.38 2006/01/12 22:08:57 chpe Exp $
  */
 
 #include "config.h"
 
 #include "ephy-toolbars-model.h"
 #include "ephy-file-helpers.h"
+#include "ephy-prefs.h"
+#include "eel-gconf-extensions.h"
+#include "eggtypebuiltins.h"
 #include "ephy-debug.h"
 
 #include <string.h>
 
-#define EPHY_TOOLBARS_XML_FILE		"epiphany-toolbars-2.xml"
-#define EPHY_TOOLBARS_XML_VERSION	"1.0"
+#define EPHY_TOOLBARS_XML_FILE		"epiphany-toolbars-3.xml"
+#define EPHY_TOOLBARS_XML_VERSION	"1.1"
 
 #define EPHY_TOOLBARS_MODEL_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_TOOLBARS_MODEL, EphyToolbarsModelPrivate))
 
 struct _EphyToolbarsModelPrivate
 {
 	char *xml_file;
+	EggTbModelFlags style;
 	guint timeout;
+	guint style_notifier_id;
 };
 
 static void ephy_toolbars_model_class_init (EphyToolbarsModelClass *klass);
@@ -97,11 +102,11 @@ save_changes (EphyToolbarsModel *model)
 }
 
 static void
-update_flags_and_save_changes (EphyToolbarsModel *model)
+update_flags (EphyToolbarsModel *model)
 {
 	EggToolbarsModel *eggmodel = EGG_TOOLBARS_MODEL (model);
 	int i, n_toolbars;
-	int flag = EGG_TB_MODEL_ACCEPT_ITEMS_ONLY;
+	int flag = 0;
 
 	n_toolbars = egg_toolbars_model_n_toolbars (eggmodel);
 
@@ -119,35 +124,55 @@ update_flags_and_save_changes (EphyToolbarsModel *model)
 		g_return_if_fail (t_name != NULL);
 
 		flags = egg_toolbars_model_get_flags (eggmodel, i);
-		flags &= ~EGG_TB_MODEL_NOT_REMOVABLE;
+		flags &= ~(EGG_TB_MODEL_NOT_REMOVABLE | EGG_TB_MODEL_STYLES_MASK);
 		flags |= flag;
+		flags |= model->priv->style;
 		egg_toolbars_model_set_flags (eggmodel, i, flags);
 	}
+}
 
+static void
+update_flags_and_save_changes (EphyToolbarsModel *model)
+{
+	update_flags (model);
 	save_changes (model);
 }
 
-static int
-get_toolbar_pos (EggToolbarsModel *model,
-		 const char *name)
+static EggTbModelFlags
+get_toolbar_style (void)
 {
-	int i, n_toolbars;
+	GFlagsClass *flags_class;
+	const GFlagsValue *value;
+	EggTbModelFlags flags = 0;
+	char *pref;
 
-	n_toolbars = egg_toolbars_model_n_toolbars (model);
-
-	for (i = 0; i < n_toolbars; i++)
+	pref = eel_gconf_get_string (CONF_INTERFACE_TOOLBAR_STYLE);
+	if (pref != NULL)
 	{
-		const char *t_name;
-
-		t_name = egg_toolbars_model_toolbar_nth (model, i);
-		g_return_val_if_fail (t_name != NULL, -1);
-		if (strcmp (name, t_name) == 0)
+		flags_class = g_type_class_ref (EGG_TYPE_TB_MODEL_FLAGS);
+		value = g_flags_get_value_by_nick (flags_class, pref);
+		if (value != NULL)
 		{
-			return i;
+			flags = value->value;
 		}
+		g_type_class_unref (flags_class);
 	}
+	flags &= EGG_TB_MODEL_STYLES_MASK;
 
-	return -1;
+	g_free (pref);
+
+	return flags;
+}
+
+static void
+toolbar_style_notifier (GConfClient *client,
+			guint cnxn_id,
+			GConfEntry *entry,
+			EphyToolbarsModel *model)
+{
+	model->priv->style = get_toolbar_style ();
+
+	update_flags (model);
 }
 
 void
@@ -155,7 +180,30 @@ ephy_toolbars_model_load (EphyToolbarsModel *model)
 {
 	EggToolbarsModel *eggmodel = EGG_TOOLBARS_MODEL (model);
 	gboolean success;
+	int i;
 
+	egg_toolbars_model_set_n_avail (eggmodel, "NavigationBack", 1);
+	egg_toolbars_model_set_n_avail (eggmodel, "NavigationForward", 1);
+	egg_toolbars_model_set_n_avail (eggmodel, "NavigationUp", 1);
+	egg_toolbars_model_set_n_avail (eggmodel, "ViewStop", 1);
+	egg_toolbars_model_set_n_avail (eggmodel, "ViewReload", 1);
+	egg_toolbars_model_set_n_avail (eggmodel, "GoHome", 1);
+	egg_toolbars_model_set_n_avail (eggmodel, "GoHistory", 1);
+	egg_toolbars_model_set_n_avail (eggmodel, "GoBookmarks", 1);
+	egg_toolbars_model_set_n_avail (eggmodel, "FileNewTab", 1);
+	egg_toolbars_model_set_n_avail (eggmodel, "FileNewWindow", 1);
+	egg_toolbars_model_set_n_avail (eggmodel, "FileOpen", 1);
+	egg_toolbars_model_set_n_avail (eggmodel, "FileSaveAs", 1);
+	egg_toolbars_model_set_n_avail (eggmodel, "FilePrint", 1);
+	egg_toolbars_model_set_n_avail (eggmodel, "FileBookmarkPage", 1);
+	egg_toolbars_model_set_n_avail (eggmodel, "ViewFullscreen", 1);
+	egg_toolbars_model_set_n_avail (eggmodel, "EditFind", 1);
+	egg_toolbars_model_set_n_avail (eggmodel, "Location", 1);
+	egg_toolbars_model_set_n_avail (eggmodel, "ToolbarGo", 1);
+	egg_toolbars_model_set_n_avail (eggmodel, "Zoom", 1);
+	egg_toolbars_model_set_n_avail (eggmodel, "ViewZoomOut", 1);
+	egg_toolbars_model_set_n_avail (eggmodel, "ViewZoomIn", 1);
+  
 	success = egg_toolbars_model_load (eggmodel, model->priv->xml_file);
 	LOG ("Loading the toolbars was %ssuccessful", success ? "" : "un");
 
@@ -165,7 +213,28 @@ ephy_toolbars_model_load (EphyToolbarsModel *model)
 	if (success == FALSE)
 	{
 		char *old_xml;
-		int toolbar;
+
+		old_xml = g_build_filename (ephy_dot_dir (),
+					    "epiphany-toolbars-2.xml",
+					    NULL);
+		success = egg_toolbars_model_load (eggmodel, old_xml);
+		g_free (old_xml);
+
+		if (success == TRUE)
+		{
+			old_xml = g_build_filename (ephy_dot_dir (),
+						    "epiphany-bookmarksbar.xml",
+						    NULL);
+			egg_toolbars_model_load (eggmodel, old_xml);
+			g_free (old_xml);
+		}
+
+		LOG ("Migration was %ssuccessful", success ? "" : "un");
+	}
+	
+	if (success == FALSE)
+	{
+		char *old_xml;
 
 		old_xml = g_build_filename (ephy_dot_dir (),
 					    "epiphany-toolbars.xml",
@@ -173,15 +242,6 @@ ephy_toolbars_model_load (EphyToolbarsModel *model)
 		success = egg_toolbars_model_load (eggmodel, old_xml);
 		g_free (old_xml);
 
-		if (success)
-		{
-			toolbar = get_toolbar_pos (eggmodel, "BookmarksBar");
-			if (toolbar != -1)
-			{
-				egg_toolbars_model_remove_toolbar (eggmodel, toolbar);
-			}
-		}
-
 		LOG ("Migration was %ssuccessful", success ? "" : "un");
 	}
 
@@ -193,6 +253,15 @@ ephy_toolbars_model_load (EphyToolbarsModel *model)
 		LOG ("Loading the default toolbars was %ssuccessful", success ? "" : "un");
 	}
 
+	/* Cleanup any empty toolbars */
+	for (i = egg_toolbars_model_n_toolbars (eggmodel)-1; i >= 0; i--)
+	{
+		if (egg_toolbars_model_n_items (eggmodel, i) == 0)
+		{
+			egg_toolbars_model_remove_toolbar (eggmodel, i);
+		}
+	}
+	
 	/* Ensure we have at least 1 toolbar */
 	if (egg_toolbars_model_n_toolbars (eggmodel) < 1)
 	{
@@ -203,12 +272,19 @@ ephy_toolbars_model_load (EphyToolbarsModel *model)
 static void
 ephy_toolbars_model_init (EphyToolbarsModel *model)
 {
-	model->priv = EPHY_TOOLBARS_MODEL_GET_PRIVATE (model);
+	EphyToolbarsModelPrivate *priv;
 
-	model->priv->xml_file = g_build_filename (ephy_dot_dir (),
-						  EPHY_TOOLBARS_XML_FILE,
-						  NULL);
+	priv = model->priv = EPHY_TOOLBARS_MODEL_GET_PRIVATE (model);
 
+	priv->xml_file = g_build_filename (ephy_dot_dir (),
+					   EPHY_TOOLBARS_XML_FILE,
+					   NULL);
+
+	priv->style = get_toolbar_style ();
+	priv->style_notifier_id = eel_gconf_notification_add
+		(CONF_INTERFACE_TOOLBAR_STYLE,
+		 (GConfClientNotifyFunc) toolbar_style_notifier, model);
+	
 	g_signal_connect_after (model, "item_added",
 				G_CALLBACK (save_changes), NULL);
 	g_signal_connect_after (model, "item_removed",
@@ -233,14 +309,19 @@ static void
 ephy_toolbars_model_finalize (GObject *object)
 {
 	EphyToolbarsModel *model = EPHY_TOOLBARS_MODEL (object);
+	EphyToolbarsModelPrivate *priv = model->priv;
 
-	if (model->priv->timeout != 0)
+	if (priv->style_notifier_id != 0)
 	{
-		g_source_remove (model->priv->timeout);
-		model->priv->timeout = 0;
+		eel_gconf_notification_remove (priv->style_notifier_id);
 	}
 
-	g_free (model->priv->xml_file);
+	if (priv->timeout != 0)
+	{
+		g_source_remove (priv->timeout);
+	}
+
+	g_free (priv->xml_file);
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
